 /*---[ menus.c ]-----------------------------------------------------
 * Copyright (C) 2000 Tomas Junnonen (majix@sci.fi)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Install menus and toolbars
 *--------------------------------------------------------------------*/

#include "menus.h"
#include "modrules.h"
#include "firestarter.h"
#include "druid.h"
#include "preferences.h"
#include "modrules.h"
#include "parse.h"

#include "rundruid.xpm"

static GnomeUIInfo firewall_menu [] = {
	GNOMEUIINFO_ITEM (N_("_Run firewall wizard"), NULL, rundruid, rundruid_xpm),
	GNOMEUIINFO_ITEM_NONE (N_("R_estart firewall"), NULL, restart_firewall_cb),
	GNOMEUIINFO_ITEM_NONE (N_("_Stop firewall"), NULL, stop_firewall_cb),
	GNOMEUIINFO_MENU_PREFERENCES_ITEM (preferences_cb, NULL),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_MENU_EXIT_ITEM (gtk_main_quit, NULL),
	GNOMEUIINFO_END
};

static GnomeUIInfo log_menu [] = {
	GNOMEUIINFO_ITEM_STOCK (N_("_Clear log"), NULL, clear_button_cb, GNOME_STOCK_PIXMAP_CLEAR),
	GNOMEUIINFO_ITEM_STOCK (N_("S_how entire log"), NULL, show_entire_log_cb, GNOME_STOCK_PIXMAP_UNDO),
	GNOMEUIINFO_ITEM_STOCK (N_("_Save log to file"), NULL, savelog_filesel_cb, GNOME_STOCK_PIXMAP_SAVE),
	GNOMEUIINFO_END
};

static GnomeUIInfo help_menu [] = {
	GNOMEUIINFO_MENU_ABOUT_ITEM (about_cb, NULL),
	GNOMEUIINFO_END
};

static GnomeUIInfo menu [] = {
	GNOMEUIINFO_SUBTREE (N_("_Firewall"), firewall_menu),
	GNOMEUIINFO_SUBTREE (N_("_Log"), log_menu),
	GNOMEUIINFO_MENU_HELP_TREE (help_menu),
	GNOMEUIINFO_END
};

static GnomeUIInfo hitlogtoolbar [] = {
	GNOMEUIINFO_ITEM (NULL, N_("Run firewall wizard"), rundruid, rundruid_xpm),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM_STOCK (NULL, N_("Clear log display"), clear_button_cb, GNOME_STOCK_PIXMAP_CLEAR),
  	GNOMEUIINFO_ITEM_STOCK (NULL, N_("Show entire firewall log"), show_entire_log_cb, GNOME_STOCK_PIXMAP_UNDO),
  	GNOMEUIINFO_ITEM_STOCK (NULL, N_("Save log to file"), savelog_filesel_cb, GNOME_STOCK_PIXMAP_SAVE),
	GNOMEUIINFO_SEPARATOR,
  	GNOMEUIINFO_ITEM_STOCK (NULL, N_("Restart firewall"), restart_firewall_cb, GNOME_STOCK_PIXMAP_REFRESH),
  	GNOMEUIINFO_ITEM_STOCK (NULL, N_("Stop firewall"), stop_firewall_cb, GNOME_STOCK_PIXMAP_STOP),
	GNOMEUIINFO_END
};

static GnomeUIInfo hitlog_menu [] = {
	GNOMEUIINFO_ITEM (N_("Allow all connections from machine"), NULL, allow_all_from_machine, NULL),
	GNOMEUIINFO_ITEM (N_("Open service to machine"), NULL, open_service_to_machine, NULL),
	GNOMEUIINFO_ITEM (N_("Open service to anyone"), NULL, open_service_to_anyone, NULL),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM (N_("Deny all connections from machine"), NULL, deny_all_from_machine, NULL),
	GNOMEUIINFO_END
};

static GnomeUIInfo dynrules_menu [] = {
	GNOMEUIINFO_ITEM (N_("Remove this rule"), NULL, clear_rule, NULL),
	GNOMEUIINFO_ITEM (N_("Remove all rules in this group"), NULL, clear_group, NULL),
	GNOMEUIINFO_SEPARATOR,
	GNOMEUIINFO_ITEM (N_("Remove all rules in all groups"), NULL, clear_all_groups, NULL),
	GNOMEUIINFO_END
};

 /*---[ install_menus_and_toolbar ]-----------------------------------
 * Install the menus and the toolbar in *window
 *--------------------------------------------------------------------*/
void
install_menus_and_toolbar (GtkWidget *window)
{
	gnome_app_create_toolbar_with_data (GNOME_APP (window), hitlogtoolbar, window);
	gnome_app_create_menus_with_data (GNOME_APP (window), menu, window);

	appbar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_USER);
	gnome_app_set_statusbar (GNOME_APP (window), appbar);
}

 /*---[ install_popup_hitlog ]----------------------------------------
 * Attach a popup menu to hitlogclist
 *--------------------------------------------------------------------*/
void
install_popup_hitlog (GtkWidget *clist)
{
	GtkWidget *popup;

	popup = gnome_popup_menu_new (hitlog_menu);
	gnome_popup_menu_attach (GTK_WIDGET (popup), GTK_WIDGET (clist), NULL);
}

 /*---[ install_popup_hitlog ]----------------------------------------
 * Attach a popup menu to the dynrules clists
 *--------------------------------------------------------------------*/
void
install_popup_dynrules (GtkWidget *clist)
{
	GtkWidget *popup;

	popup = gnome_popup_menu_new (dynrules_menu);
	gnome_popup_menu_attach (GTK_WIDGET (popup), GTK_WIDGET (clist), NULL);
}